StateManagementGenerator class

Constructors

StateManagementGenerator({required String name, required String className, required String providerName, required String? stateMgmt, required bool useFreezed})

Properties

className String
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
providerName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateMgmt String?
final
useFreezed bool
final

Methods

generate() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited