SourceTemplate class

Constructors

SourceTemplate({required String className, required String featureName, bool useFreezed = false})

Properties

className String
final
featureName String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useFreezed bool
final

Methods

getEntityTemplate() String
getFileTemplates(String basePath) Map<String, String>
Additional method to get the list of files that need to be generated
getFreezedEntityTemplate() String
getFreezedModelTemplate() String
getLocalDataSourceImplTemplate() String
getLocalDataSourceTemplate() String
getModelTemplate() String
getRegularEntityTemplate() String
getRegularModelTemplate() String
getRemoteDataSourceImplTemplate() String
getRemoteDataSourceTemplate() String
getRepositoryImplTemplate() String
getRepositoryTemplate() String
getScreenTemplate() String
getUseCaseTemplate() String
getWidgetTemplate() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited