TestTemplateGenerator class
Constructors
- TestTemplateGenerator({required String className, required String featureName, required String providerName, bool useFreezed = false})
Properties
- className → String
-
final
- featureName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- providerName → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- useFreezed → bool
-
final
Methods
-
getAllTestTemplates(
String basePath) → Map< String, String> -
getControllerTestPath(
String stateMgmt, String basePath) → String -
getControllerTestTemplate(
String stateMgmt) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited